# eric7.MicroPython.MicroPythonWebreplParametersDialog

Module implementing a dialog to enter the parameters for the WebREPL server.

### Global Attributes

None

### Classes

MicroPythonWebreplParametersDialog | Class implementing a dialog to enter the parameters for the WebREPL server.

### Functions

None

## MicroPythonWebreplParametersDialog

Class implementing a dialog to enter the parameters for the WebREPL server.

### Derived from

QDialog, Ui_MicroPythonWebreplParametersDialog

### Class Attributes

None

### Class Methods

None

### Methods

MicroPythonWebreplParametersDialog | Constructor
__updateOk | Private slot to update the enabled state of the OK button.
getParameters | Public method to retrieve the entered data.

### Static Methods

None

#### MicroPythonWebreplParametersDialog (Constructor)

MicroPythonWebreplParametersDialog(parent=None)

Constructor

parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### MicroPythonWebreplParametersDialog.__updateOk

__updateOk()

Private slot to update the enabled state of the OK button.

#### MicroPythonWebreplParametersDialog.getParameters

getParameters()

Public method to retrieve the entered data.

Return:
  tuple containing the password

Return Type:
  tuple of (str,)

Up